Very old ZODB programming guide — ZODB documentation

# Very old ZODB programming guide

> This guide is based heavily on the work of A. M. Kuchling who wrote the original guide back in 2002 and which was published under the GNU Free Documentation License, Version 1.1. See the appendix entitled “GNU Free Documentation License” for more information.

- Introduction
  - What is the ZODB?
  - OODBs vs. Relational DBs
  - What is ZEO?
  - About this guide
  - Acknowledgements
- ZODB Programming
  - Installing ZODB
  - How ZODB Works
  - Opening a ZODB
  - Using a ZODB Configuration File
  - Writing a Persistent Class
  - Rules for Writing Persistent Classes
  - Writing Persistent Classes
- ZEO
  - How ZEO Works
  - Installing ZEO
  - Testing the ZEO Installation
  - ZEO Programming Notes
  - Sample Application: chatter.py
- Transactions and Versioning
  - Committing and Aborting
  - Subtransactions
  - Undoing Changes
  - Versions
  - Multithreaded ZODB Programs
- Related Modules
  - `persistent.mapping.PersistentMapping`
  - `persistent.list.PersistentList`
  - BTrees Package
- Resources
- GNU Free Documentation License
  - Applicability and Definitions
  - Verbatim Copying
  - Copying in Quantity
  - Modifications
  - Combining Documents
  - Collections of Documents
  - Aggregation With Independent Works
  - Translation
  - Termination
  - Future Revisions of This Licence